@@ -1,8 +1,12 @@
 
 from django.conf.urls import url, include
+from django.core.urlresolvers import reverse
+
+from . import http
 
 # TODO: Add other patterns to allow introspection?
 
+
 class Api(object):
     '''Helper class for registering many Publishers in one URL namespace'''
     def __init__(self, name):
@@ -11,7 +15,9 @@ class Api(object):
 
     def patterns(self, flat=False):
         urlpatterns = [
-            url(r'^%s/' % name, include(child.patterns()))
+            url(r'^$', self.index),
+        ] + [
+            url(r'^%s/' % name, include(child.patterns(self.name)))
             for name, child in self.children.items()
         ]
         if flat:
@@ -20,6 +26,13 @@ class Api(object):
             url(r'^%s/' % self.name, include(urlpatterns)),
         ]
 
+    def index(self, request, *args, **kwargs):
+        '''Return a dict of publisher name: url'''
+        return http.JsonResponse(dict(
+            (name, reverse('%s_%s_list_default' % (self.name, name), kwargs=kwargs))
+            for name, child in self.children.items()
+        ))
+
     def register(self, child, name=None):
         if name is None:
             name = getattr(child, 'api_name', child.__class__.__name__.lower())
@@ -31,6 +44,7 @@ class Api(object):
 
 APIS = {}
 
+
 def register(name, *args):
     try:
         api = APIS[name]
@@ -40,6 +54,7 @@ def register(name, *args):
         api.register(resource)
     return api
 
+
 def autodiscover():
     from django.conf import settings
     from django.utils.importlib import import_module
@@ -58,9 +73,9 @@ def autodiscover():
             if module_has_submodule(mod, 'serialiser'):
                 raise
 
+
 def patterns(flat=False):
     patterns = []
     for api in APIS.values():
         patterns.extend(api.patterns(flat=flat))
     return patterns
-
