@@ -1,9 +1,11 @@
 
 from django.conf.urls import url
 from django.core.paginator import Paginator
+from django.shortcuts import get_object_or_404
 
 from . import http
 
+
 class Publisher(object):
     def __init__(self, request, *args, **kwargs):
         self.request = request
@@ -12,12 +14,13 @@ class Publisher(object):
 
     # XXX Need some names/labels to build url pattern names?
     @classmethod
-    def patterns(cls):
+    def patterns(cls, api_name=None):
         '''
         Add this to your url patterns like:
             ( '^foo/', include(mypublisher.patterns()), ),
         /                       default object list
         /(action)/              list operation
+        /(action)/(option)/     list operation with extra argument
         /object/(id)/           instance view
         /object/(id)/(action)/  custom action on instance
         '''
@@ -26,11 +29,36 @@ class Publisher(object):
             self = cls(request, *args, **kwargs)
             return self.dispatch(request, *args, **kwargs)
 
+        if api_name:
+            name = '_'.join([api_name, cls.api_name])
+        else:
+            name = self.api_name
+
         return [
-            url(r'^object/(?P<object_id>[-\w]+)/(?P<action>\w+)/?$', view),
-            url(r'^object/(?P<object_id>[-\w]+)/?$',                 view),
-            url(r'^(?P<action>\w+)/?$',                           view),
-            url(r'^$',                                            view),
+            url(r'^object/(?P<object_id>[-\w]+)/(?P<action>\w+)/(?P<argument>.+)/?$',
+                view,
+                name='%s_object_action_arg' % name,
+            ),
+            url(r'^object/(?P<object_id>[-\w]+)/(?P<action>\w+)/?$',
+                view,
+                name='%s_object_action' % name,
+            ),
+            url(r'^object/(?P<object_id>[-\w]+)/?$',
+                view,
+                name='%s_object_default' % name,
+            ),
+            url(r'^(?P<action>\w+)/(?P<argument>.+)/$',
+                view,
+                name='%s_list_action_arg' % name,
+            ),
+            url(r'^(?P<action>\w+)/?$',
+                view,
+                name='%s_list_action' % name,
+            ),
+            url(r'^$',
+                view,
+                name='%s_list_default' % name,
+            ),
         ]
 
     def dispatch(self, request, action='default', object_id=None, **kwargs):
@@ -72,13 +100,15 @@ class Publisher(object):
                 'offset': page.start_index() - 1,
                 'limit': page_size,
                 'count': paginator.count,
+                'has_next': page.has_next(),
+                'has_prev': page.has_previous(),
             },
             'objects': page.object_list,
         }
 
     def get_data(self):
         '''Retrieve data from request'''
-        if self.request.META['CONTENT_TYPE'] in ['application/json',]:
+        if self.request.META['CONTENT_TYPE'] in ['application/json', ]:
             if not self.request.body:
                 return None
             return http.loads(self.request.body)
@@ -109,16 +139,22 @@ class Publisher(object):
         obj = serialiser.inflate_object(self.get_data(), obj)
         return self.render_single_object(obj, serialiser)
 
-    def render_single_object(self, obj, serialiser=None):
+    def render_single_object(self, obj, serialiser=None, **response_kwargs):
         if serialiser is None:
             serialiser = self.get_serialiser()
         data = serialiser.deflate_object(obj, publisher=self)
-        return http.JsonResponse(data)
+        return self.create_response(data, **response_kwargs)
 
     def create_response(self, context, **response_kwargs):
-        return http.JsonResponse(context)
+        response_class = response_kwargs.pop('response_class', http.JsonResponse)
+        return response_class(context, **response_kwargs)
+
 
 class ModelPublisher(Publisher):
+    @property
+    def model(self):
+        '''By default, we try to get the model from out serialiser'''
+        return self.serialiser._meta.model
 
     # Auto-build serialiser from model class?
 
@@ -126,5 +162,5 @@ class ModelPublisher(Publisher):
         return self.model.objects.all()
 
     def get_object(self, object_id):
-        return self.get_object_list().get(pk=object_id)
+        return get_object_or_404(self.get_object_list(), pk=object_id)
 
